@@ -1567,6 +1567,20 @@ create_transaction(XferDialog *xferData, Timespec *ts,
         xferData->transaction_cb(trans, xferData->transaction_user_data);
 }
 
+static void
+swap_amount (gnc_commodity **from, gnc_commodity **to, gnc_numeric *value,
+             gnc_numeric *from_amt, gnc_numeric *to_amt)
+{
+    gnc_commodity *tmp = *from;
+    gnc_numeric *tmp_amt = from_amt;
+    *from = *to;
+    *to = tmp;
+    from_amt = to_amt;
+    to_amt = tmp_amt;
+    *value = gnc_numeric_invert (*value);
+    *value = round_price(*from, *to, *value);
+}
+
 static gnc_numeric
 swap_commodities(gnc_commodity **from, gnc_commodity **to, gnc_numeric value)
 {
@@ -1595,6 +1609,12 @@ create_price(XferDialog *xferData, Timespec ts)
         return;
 
     value = gnc_amount_edit_get_amount(GNC_AMOUNT_EDIT(xferData->price_edit));
+    /* Try to be consistent about how quotes are installed. */
+    if (from == gnc_default_currency() ||
+        ((to != gnc_default_currency()) &&
+         (strcmp (gnc_commodity_get_mnemonic(from),
+                  gnc_commodity_get_mnemonic(to)) < 0)))
+        swap_amount (&from, &to, &value, &from_amt, &to_amt);
 
 /* Normally we want to store currency rates such that the rate > 1 and commodity
  * prices in terms of a currency regardless of value. However, if we already
@@ -2409,7 +2429,6 @@ gboolean gnc_xfer_dialog_run_exchange_dialog(
     gboolean swap_amounts = FALSE;
     gnc_commodity *txn_cur = xaccTransGetCurrency(txn);
     gnc_commodity *reg_com = xaccAccountGetCommodity(reg_acc);
-    gnc_numeric dialog_rate = *exch_rate;
 
     g_return_val_if_fail(txn_cur, TRUE);
 
@@ -2471,14 +2490,13 @@ gboolean gnc_xfer_dialog_run_exchange_dialog(
         gnc_xfer_dialog_select_to_currency(xfer, txn_cur);
         gnc_xfer_dialog_select_from_currency(xfer, xfer_com);
         if (!gnc_numeric_zero_p(*exch_rate))
-            dialog_rate = gnc_numeric_invert(*exch_rate);
+            *exch_rate = gnc_numeric_invert(*exch_rate);
         amount = gnc_numeric_neg(amount);
     }
     else
     {
         gnc_xfer_dialog_select_to_currency(xfer, xfer_com);
         gnc_xfer_dialog_select_from_currency(xfer, txn_cur);
-
         if (xaccTransUseTradingAccounts ( txn ))
             amount = gnc_numeric_neg(amount);
     }
@@ -2495,11 +2513,14 @@ gboolean gnc_xfer_dialog_run_exchange_dialog(
      */
 
     /* Set the exchange rate */
-    gnc_xfer_dialog_set_price_edit(xfer, dialog_rate);
+    gnc_xfer_dialog_set_price_edit(xfer, *exch_rate);
 
     /* and run it... */
     if (gnc_xfer_dialog_run_until_done(xfer) == FALSE)
         return TRUE;
+    /* If we inverted the rate for the dialog, invert it back. */
+    if (swap_amounts)
+        *exch_rate = gnc_numeric_invert(*exch_rate);
 
     return FALSE;
 }
